/*
 * Name:    mtake.c
 *
 * Purpose: Take motor commands from an external process.
 *
 * Author:  William Lavender
 *
 *-------------------------------------------------------------------------
 *
 * Copyright 1999, 2001 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "motor.h"
#include "command.h"

#ifdef OS_UNIX
#include "mx_coprocess.h"
#endif /* OS_UNIX */

int
motor_take_fn( int argc, char *argv[] )
{
	const char cname[] = "take";

#ifndef OS_UNIX
	fprintf(output,
"Error: '%s' is not currently implemented for non-Unix systems.\n", cname);

	return FAILURE;

#else /* OS_UNIX */

	MX_COPROCESS coprocess;
	char **argv_ptr;
	FILE *saved_output;
	char buffer[250];
	int status;
	size_t length;
	char *ptr;
	char prompt[60];
	mx_status_type mx_status;

#if 1
	fprintf(output, "The '&' or 'take' command is no longer supported.\n");
	return FAILURE;
#endif

	if ( argc <= 2 ) {
		fprintf(output, "Usage: %s 'external command line'\n", cname);
		return FAILURE;
	}

	argv_ptr = argv + 2;

	mx_status = mx_create_coprocess( &coprocess, argv_ptr );

	if ( mx_status.code != MXE_SUCCESS ) {
		fprintf(output,
			"%s: Attempt to invoke command '%s' failed.\n",
			cname, argv_ptr[0]);

		return FAILURE;
	}

	/* Redirect output from commands to the coprocess. */

	saved_output = output;

	output = coprocess.to_coprocess;

	/* Now read a series of commands from the coprocess. */

	status = SUCCESS;

	while(1) {
		/* Send a prompt so that the coprocess will know that
		 * we are ready for a command.
		 */

		sprintf( prompt, "$%s(%d)\n", cmd_program_name(), status );

		fputs( prompt, output );

		/* Read the command. */

		fgets( buffer, sizeof buffer, coprocess.from_coprocess );

		if ( feof( coprocess.from_coprocess ) ) {
			fprintf( saved_output,
		"%s: External program has completed successfully.\n", cname );

			break;    /* Exit the while() loop. */
		}

		if ( ferror( coprocess.from_coprocess ) ) {
			fprintf( saved_output,
				"%s: ferror() seen for coprocess.\n", cname );

			break;    /* Exit the while() loop. */
		}

		/* Remove any trailing newline characters. */

		length = strlen(buffer);

		if ( length <= 0 ) {
			fprintf( saved_output,
	"%s: Bad string length %ld for command line read from coprocess.\n",
				cname, (long) length );
			break;    /* Exit the while() loop. */
		}

		ptr = buffer + length - 1;

		if ( *ptr == '\n' ) {
			*ptr = '\0';
		}

#if 0
		fprintf( saved_output, "%s: Executing command '%s'\n",
				cname, buffer );
#endif

		/* Now execute the command. */

		status = cmd_execute_command_line( command_list_length,
				command_list, buffer );

		if ( status != SUCCESS ) {
			fprintf( saved_output,
			"%s: Error encountered executing command line '%s'\n",
				cname, buffer );
		}
	}

	output = saved_output;

	mx_status = mx_kill_coprocess( &coprocess );

	if ( mx_status.code != MXE_SUCCESS )
		return FAILURE;

	return SUCCESS;

#endif /* OS_UNIX */
}

